@@ -202,8 +202,8 @@ namespace BOOM {
     double prob(uint i) const;
     void set_probs(const Vector &pi);
     void set_prob(double prob, uint i);
-    ParamVector parameter_vector() override;
-    const ParamVector parameter_vector() const override;
+    std::vector<Ptr<Params>> parameter_vector() override;
+    const std::vector<Ptr<Params>> parameter_vector() const override;
     void unvectorize_params(const Vector &v, bool minimal = true) override;
 
     std::ostream &print(std::ostream &out) const override;
