@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2007 Steven L. Scott
 
@@ -18,49 +19,41 @@
 #ifndef BOOM_MARKOV_CONJUGATE_SAMPLER_HPP
 #define BOOM_MARKOV_CONJUGATE_SAMPLER_HPP
 
-#include <Models/PosteriorSamplers/PosteriorSampler.hpp>
-#include <Models/MarkovModel.hpp>
-#include <Models/ProductDirichletModel.hpp>
-#include <Models/DirichletModel.hpp>
-#include <distributions/rng.hpp>
+#include "Models/DirichletModel.hpp"
+#include "Models/MarkovModel.hpp"
+#include "Models/PosteriorSamplers/PosteriorSampler.hpp"
+#include "Models/ProductDirichletModel.hpp"
+#include "distributions/rng.hpp"
 
-namespace BOOM{
-  class MarkovConjSampler
-    : public PosteriorSampler
-  {
+namespace BOOM {
+  class MarkovConjSampler : public PosteriorSampler {
    public:
-    MarkovConjSampler(MarkovModel * Mod,
-                      Ptr<ProductDirichletModel> Q,
-                      Ptr<DirichletModel> pi0,
+    MarkovConjSampler(MarkovModel *Mod, const Ptr<ProductDirichletModel> &Q,
+                      const Ptr<DirichletModel> &pi0,
                       RNG &seeding_rng = GlobalRng::rng);
-    MarkovConjSampler(MarkovModel * Mod,
-                      Ptr<ProductDirichletModel> Q,
+    MarkovConjSampler(MarkovModel *Mod, const Ptr<ProductDirichletModel> &Q,
                       RNG &seeding_rng = GlobalRng::rng);
-    MarkovConjSampler(MarkovModel * Mod,
-                      const Matrix & Nu,
+    MarkovConjSampler(MarkovModel *Mod, const Matrix &Nu,
                       RNG &seeding_rng = GlobalRng::rng);
-    MarkovConjSampler(MarkovModel * Mod,
-                      const Matrix & Nu,
-                      const Vector & nu,
+    MarkovConjSampler(MarkovModel *Mod, const Matrix &Nu, const Vector &nu,
                       RNG &seeding_rng = GlobalRng::rng);
 
-    double logpri()const override;
+    double logpri() const override;
     void draw() override;
     void find_posterior_mode(double epsilon = 1e-5) override;
-    bool can_find_posterior_mode() const override {
-      return true;
-    }
+    bool can_find_posterior_mode() const override { return true; }
 
-    const Matrix & Nu()const;
-    const Vector & nu()const;  // throws if pi0_ is not set
+    const Matrix &Nu() const;
+    const Vector &nu() const;  // throws if pi0_ is not set
    private:
-    MarkovModel * mod_;
+    MarkovModel *mod_;
     Ptr<ProductDirichletModel> Q_;
     Ptr<DirichletModel> pi0_;
+
    protected:
-    void check_pi0()const;
-    void check_nu()const;
+    void check_pi0() const;
+    void check_nu() const;
     mutable Vector wsp;
   };
 }  // namespace BOOM
-#endif// BOOM_MARKOV_CONJUGATE_SAMPLER_HPP
+#endif  // BOOM_MARKOV_CONJUGATE_SAMPLER_HPP
