@@ -368,6 +368,11 @@ namespace BOOM {
     }
     if (total == 0) {
       report_error("normalizing constant is zero in Vector::normalize_prob");
+    } else if (!std::isfinite(total)) {
+      std::ostringstream err;
+      err << "Infinite or NaN probabilities in call to 'normalize_prob': "
+          << *this;
+      report_error(err.str());
     }
     operator/=(total);
     return *this;
@@ -379,13 +384,16 @@ namespace BOOM {
     int n = size();
     if (n == 0) {
       report_error("Vector::normalize_logprob called for empty vector");
+    } else if (n == 1) {
+      x[0] = 1.0;
+    } else {
+      double m = max();
+      for (uint i = 0; i < n; ++i) {
+        x[i] = std::exp(x[i] - m);
+        nc += x[i];
+      }
+      x /= nc;
     }
-    double m = max();
-    for (uint i = 0; i < n; ++i) {
-      x[i] = std::exp(x[i] - m);
-      nc += x[i];
-    }
-    x /= nc;
     return *this;  // might want to change this
   }
 
@@ -568,7 +576,7 @@ namespace BOOM {
   Vector operator+(const VectorView &x, double a) {
     return ConstVectorView(x) + a;
   }
-      
+
   // Vector-double subraction
   Vector operator-(double a, const ConstVectorView &x) {
     Vector ans(x.size(), a);
@@ -636,8 +644,8 @@ namespace BOOM {
   Vector operator/(const Vector &x, double a) {
     return ConstVectorView(x) / a;
   }
-  
-  
+
+
   namespace {
     template <class V1, class V2>
     Vector vector_add(const V1 &v1, const V2 &v2) {
@@ -729,7 +737,7 @@ namespace BOOM {
   Vector operator/(const ConstVectorView &x, const Vector &y) {
     return vector_divide(x, y);
   }
-  
+
 
   // unary transformations
   Vector operator-(const Vector &x) {
