@@ -49,14 +49,14 @@ namespace BOOM {
     return new FineNowcastingData(*this);
   }
 
-  ostream &FineNowcastingData::display(ostream &out) const {
+  std::ostream &FineNowcastingData::display(std::ostream &out) const {
     out << "x = " << x_->x() << endl
         << "   y = " << coarse_observation_ << " ["
-        << (coarse_observation_observed_ ? string("observed")
-                                         : string("missing"))
+        << (coarse_observation_observed_ ? std::string("observed")
+                                         : std::string("missing"))
         << "]" << endl
         << "   contains_end = "
-        << (contains_end_ ? string("contains_end") : string("regular")) << endl
+        << (contains_end_ ? std::string("contains_end") : std::string("regular")) << endl
         << "   fraction in previous period = (" << fraction_in_initial_period_
         << ")" << endl;
     return out;
@@ -88,7 +88,7 @@ namespace BOOM {
         contains_end_(contains_end),
         owns_matrix_(owns_matrix) {
     if (fraction_in_initial_period > 1.0 || fraction_in_initial_period <= 0.0) {
-      ostringstream err;
+      std::ostringstream err;
       err << "Error in constructor for AccumulatorTransitionMatrix:" << endl
           << "fraction_in_initial_period must be in (0, 1]" << endl;
       report_error(err.str());
@@ -127,7 +127,7 @@ namespace BOOM {
                                    const SparseVector &Z, bool new_time,
                                    double fraction_in_initial_period,
                                    const VEC &v) {
-    ostringstream err;
+    std::ostringstream err;
     int state_dim = T->nrow();
     err << "incompatible sizes in AccumulatorTransitionMatrix multiplication"
         << endl
@@ -141,9 +141,9 @@ namespace BOOM {
   //----------------------------------------------------------------------
 
   namespace {
-    // Keep in mind that you might not be multiplying a state vector.
-    // You probably are, but you might be multiplying a random column in
-    // a variance matrix, etc.
+    // Keep in mind that you might not be multiplying a state vector.  You
+    // probably are, but you might be multiplying a random column in a variance
+    // matrix, etc.
     template <class VEC>
     Vector Multiply(const SparseKalmanMatrix *T, const SparseVector &Z,
                     bool contains_end, double fraction_in_initial_period,
@@ -396,6 +396,7 @@ namespace BOOM {
   ASSR::AggregatedStateSpaceRegression(int number_of_predictors)
       : regression_(new RegressionModel(number_of_predictors)),
         observation_model_(new GaussianModel(0, 0)) {
+    regression_->suf().dcast<NeRegSuf>()->allow_non_finite_responses(true);
     add_state(new AggregatedRegressionStateModel(regression_));
   }
 
@@ -407,7 +408,7 @@ namespace BOOM {
         regression_(rhs.regression_->clone()),
         observation_model_(rhs.observation_model_->clone()) {
     add_state(new AggregatedRegressionStateModel(regression_));
-    for (int s = 1; s < rhs.nstate(); ++s) {
+    for (int s = 1; s < rhs.number_of_state_models(); ++s) {
       add_state(rhs.state_model(s)->clone());
     }
     clear_data();
@@ -457,6 +458,10 @@ namespace BOOM {
     double y = alpha[state_dim - 2];
     // y is the imputed fine-scale observation from the Kalman filter.
 
+    if (!std::isfinite(y)) {
+      report_error("Observation is not finite.");
+    }
+
     Ptr<RegressionData> dp(regression_->dat()[t]);
     // The state_mean is computed using the observation_matrix from
     // the client model, available from ScalarStateSpaceModelBase.
